pygeodesy.ltp.ChLVa

Package pygeodesy :: Module ltp :: Class ChLVa |
[frames] | no frames]

# Class ChLVa

              object --+
                       |
                   _ChLV --+
                           |
      object --+           |
               |           |
    named._Named --+       |
                   |       |
    named._NamedBase --+   |
                       |   |
          LocalCartesian --+
                           |
                          ChLVa

Conversion between WGS84 geodetic and Swiss projection coordinates using the Approximate formulas, page 13.

See Also: Older references.

Instance Methods
__init__(self, name=`'``Bern``'`) New Approximate WGS84-Swiss ChLVa converter, centered at Bern, Ch. |
forward(self, latlonh, lon=None, height=0, M=None, **name) Convert WGS84 geodetic to Swiss projection coordinates. |
reverse(self, enh_, n=None, h_=0, M=None, **name) Convert Swiss projection to WGS84 geodetic coordinates. |
Inherited from `LocalCartesian`: `__eq__`, `reset`, `toStr` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others`, `toRepr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `LocalCartesian`: `M`, `datum`, `ecef`, `ellipsoid`, `height0`, `lat0`, `latlonheight0`, `lon0`, `lon00` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, name=`'``Bern``'`) (Constructor) |
New Approximate WGS84-Swiss ChLVa converter, centered at Bern, Ch. Arguments: `name` - Optional `name=Bern.name` (`str`). Raises: `LocalError` - If `latlonh0` not `LatLon`, LatLon4Tuple, Ltp, LocalCartesian or Ecef9Tuple or `latlonh0`, `lon0`, `height0` or `lon00` invalid. `TypeError` - Invalid `ecef` or not EcefKarney. Overrides: object.__init__

### forward (self, latlonh, lon=None, height=0, M=None, **name) |
Convert WGS84 geodetic to Swiss projection coordinates. Must be overloaded. Arguments: `latlonh` - Either a `LatLon`, Ltp or `scalar` (geodetic) latitude (`degrees`). `lon` - Optional, `scalar` (geodetic) longitude (`degrees`) iff `latlonh` is `scalar`, ignored otherwise. `height` - Optional, height, vertically above (or below) the surface of the ellipsoid (`meter`) iff `latlonh` and `lon` are `scalar`, ignored otherwise. `M` - If `True`, return the concatenated rotation EcefMatrix iff available and for `ChLV` only, `None` otherwise (`bool`). `name` - Optional `name=NN` (`str`). Returns: A ChLV9Tuple`(Y, X, h_, lat, lon, height, ltp, ecef, M)` with the unfalsed Swiss Y, X coordinates, Swiss h_ height, the given geodetic `lat`, `lon` and `height`, `ecef` (Ecef9Tuple) at Bern, Ch, rotation matrix `M` and `ltp` this `ChLV`, `ChLVa` or `ChLVe` instance. Raises: `LocalError` - Invalid or non-`scalar` `latlonh`, `lon` or `height`. Overrides: LocalCartesian.forward (inherited documentation)

### reverse (self, enh_, n=None, h_=0, M=None, **name) |
Convert Swiss projection to WGS84 geodetic coordinates. Arguments: `enh_` - A Swiss projection (ChLV9Tuple) or the `scalar`, falsed Swiss E_LV95 or y_LV03 easting (`meter`). `n` - Falsed Swiss N_LV85 or x_LV03 northing (`meter`) iff `enh_` is `scalar`, ignored otherwise. `h_` - Swiss h' height (`meter`) iff `enh_` and `n` are `scalar`, ignored otherwise. `M` - If `True`, return the concatenated rotation EcefMatrix iff available and for `ChLV` only, `None` otherwise (`bool`). `name` - Optional `name=NN` (`str`). Returns: A ChLV9Tuple`(Y, X, h_, lat, lon, height, ltp, ecef, M)` with the unfalsed Swiss Y, X coordinates, Swiss h_ height, the given geodetic `lat`, `lon` and `height`, `ecef` (Ecef9Tuple) at Bern, Ch, rotation matrix `M` and `ltp` this `ChLV`, `ChLVa` or `ChLVe` instance. Raises: `LocalError` - Invalid or non-`scalar` `enh_`, `n` or `h_`. Overrides: LocalCartesian.reverse (inherited documentation)